@@ -1325,7 +1325,7 @@ test_enum_param(TestEnum e)
 /**
  * test_struct_a_clone:
  * @a: the structure
- * @a_out: the cloned structure
+ * @a_out: (out caller-allocates): the cloned structure
  *
  * Make a copy of a TestStructA
  */
@@ -1339,7 +1339,7 @@ test_struct_a_clone (TestStructA *a,
 /**
  * test_struct_b_clone:
  * @b: the structure
- * @b_out: the cloned structure
+ * @b_out: (out): the cloned structure
  *
  * Make a copy of a TestStructB
  */
@@ -1777,6 +1777,24 @@ test_obj_do_matrix (TestObj *obj, const char *somestr)
   return TEST_OBJ_GET_CLASS (obj)->matrix (obj, somestr);
 }
 
+/**
+ * test_object_null_in:
+ * @obj: (allow-none) A #TestObj
+ */
+void
+test_object_null_in (TestObj *obj)
+{
+}
+
+/**
+ * test_object_null_out:
+ * @obj: (allow-none) (out) A #TestObj
+ */
+void
+test_object_null_out (TestObj **obj)
+{
+}
+
 typedef struct _CallbackInfo CallbackInfo;
 
 struct _CallbackInfo
@@ -2162,6 +2180,36 @@ test_wi_802_1x_static_method (int x)
   return 2*x;
 }
 
+/* floating gobject */
+G_DEFINE_TYPE(TestFloating, test_floating, G_TYPE_INITIALLY_UNOWNED);
+
+static void
+test_floating_finalize(GObject *object)
+{
+  g_assert(!g_object_is_floating (object));
+
+  G_OBJECT_CLASS(test_floating_parent_class)->finalize(object);
+}
+
+static void
+test_floating_class_init (TestFloatingClass *klass)
+{
+  GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
+  gobject_class->finalize = test_floating_finalize;
+}
+
+static void
+test_floating_init (TestFloating *obj)
+{
+}
+
+TestFloating *
+test_floating_new (void)
+{
+  return g_object_new (TEST_TYPE_FLOATING, NULL);
+}
+
+
 /**
  * test_torture_signature_0:
  * @x:
